<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Event;

defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Event\Backport\ResultAware;
use Akeeba\Component\LoginGuard\Administrator\Event\Backport\ResultAwareInterface;
use Akeeba\Component\LoginGuard\Administrator\Event\Backport\ResultTypeBooleanAware;
use Akeeba\Component\LoginGuard\Administrator\Table\TfaTable;
use DomainException;
use Joomla\CMS\Event\AbstractImmutableEvent;
use Joomla\CMS\User\User;

/**
 * Concrete Event class for the onLoginGuardMfaValidate event
 *
 * @package     Akeeba\Component\LoginGuard\Administrator\Event
 *
 * @since       6.0.0
 */
class Validate extends AbstractImmutableEvent implements ResultAwareInterface
{
	use ResultAware;
	use ResultTypeBooleanAware;

	/** @inheritdoc */
	public function __construct(TfaTable $record, User $user, string $code)
	{
		parent::__construct('onLoginGuardMfaValidate', [
			'record' => $record,
			'user'   => $user,
			'code'   => $code,
		]);
	}

	/**
	 * Validate the value of the 'record' named parameter
	 *
	 * @param   TfaTable  $value
	 *
	 * @return  TfaTable
	 * @since   6.0.0
	 */
	public function setRecord(TfaTable $value): TfaTable
	{
		if (empty($value))
		{
			throw new DomainException(sprintf('Argument \'record\' of event %s must be a TfaTable object', $this->name));
		}

		return $value;
	}

	/**
	 * Validate the value of the 'user' named parameter
	 *
	 * @param   User  $value
	 *
	 * @return  User
	 * @since   6.0.0
	 */
	public function setUser(User $value): User
	{
		if (empty($value) || ($value->id <= 0) || ($value->guest == 1))
		{
			throw new DomainException(sprintf('Argument \'user\' of event %s must be a non-guest User object', $this->name));
		}

		return $value;
	}

	/**
	 * Validate the value of the 'code' named parameter
	 *
	 * @param   string|null  $value
	 *
	 * @return  string|null
	 * @since   6.0.0
	 */
	public function setCode(?string $value): ?string
	{
		// No validation necessary, the type check in the method options is enough
		return $value;
	}
}