<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Model\CaptiveModel;
use Akeeba\Component\LoginGuard\Administrator\View\Captive\HtmlView;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Session\Session;

/** @var HtmlView $this */
/** @var CaptiveModel $model */

$model           = $this->getModel();
$allowRememberMe = ComponentHelper::getParams('com_loginguard')->get('allow_rememberme', 1) == 1;

?>
<div class="loginguard-captive">
    <h3 id="loginguard-title">
	    <?php if (!empty($this->renderOptions['help_url'])): ?>
		<div class="loginguard-title-help">
        		<a
					href="<?= $this->renderOptions['help_url'] ?>"
					class="btn btn-sm btn-secondary"
					target="_blank"
					title="<?= Text::_('COM_LOGINGUARD_LBL_HELP') ?>"
		>
					<span class="icon icon-question-sign" aria-hidden="true"></span>
					<span class="loginguard-visually-hidden"><?= Text::_('COM_LOGINGUARD_LBL_HELP') ?></span>
        	</a>
        </div>
	    <?php endif;?>
		<div class="loginguard-title-main">
			<?php if (!empty($this->title)): ?>
				<?= $this->title ?> <small> &ndash;
			<?php endif; ?>
			<?php if (!$this->allowEntryBatching): ?>
				<?= $this->escape($this->record->title) ?>
			<?php else: ?>
				<?= $this->escape($this->getModel()->translateMethodName($this->record->method)) ?>
			<?php endif; ?>
			<?php if (!empty($this->title)): ?>
			</small>
			<?php endif; ?>
		</div>
    </h3>

	<?php if ($this->renderOptions['pre_message']): ?>
        <div class="loginguard-captive-pre-message">
	        <?= $this->renderOptions['pre_message'] ?>
        </div>
	<?php endif; ?>

	<form action="<?= Route::_('index.php?option=com_loginguard&task=captive.validate&record_id=' . ((int) $this->record->id)) ?>"
			id="loginguard-captive-form"
			method="post"
	>
		<?= HTMLHelper::_('form.token') ?>

	    <div id="loginguard-captive-form-method-fields">
		    <?php if ($this->renderOptions['field_type'] == 'custom'): ?>
			    <?= $this->renderOptions['html']; ?>
		    <?php else:
                $js = <<< JS
; // Fix broken third party Javascript...
window.addEventListener("DOMContentLoaded", function() {
    document.getElementById('loginGuardCode').focus();
});

JS;
		        $this->document->addScriptDeclaration($js);

            ?>
                <div class="loginguard-captive-form-input-container">
					<?php if ($this->renderOptions['label']): ?>
                    <label for="loginGuardCode" class="loginguard-captive-form-input-label">
	                    <?= $this->renderOptions['label'] ?>
                    </label>
					<?php endif; ?>
					<div class="loginguard-captive-form-input <?= $this->renderOptions['label'] ? '' : 'loginguard-captive-form-input-nolabel' ?>">
						<input type="<?= $this->renderOptions['input_type'] ?>"
							   name="code"
							   value=""
							<?php if (!empty($this->renderOptions['placeholder'])): ?>
								placeholder="<?= $this->renderOptions['placeholder'] ?>"
							<?php endif; ?>
							   id="loginGuardCode"
							   class=""
						>
					</div>
                </div>

		    <?php endif;?>

		    <?php if (!empty($this->browserId) && $allowRememberMe): ?>
				<div id="loginguard-captive-form-remember-me"
						class="loginguard-captive-form-input-container">
					<label for="loginguard-rememberme-yes" class="loginguard-captive-form-input-label">
					    <?= Text::_('JGLOBAL_REMEMBER_ME') ?>
					</label>
					<div class="loginguard-captive-form-input">
						<div class="loginguard-toggle" id="loginguard-rememberme-container">
							<input id="loginguard-rememberme-yes" type="radio" name="rememberme" value="1" checked />
							<label for="loginguard-rememberme-yes" class="green"><?= Text::_('JYES') ?></label>
							<input id="loginguard-rememberme-no" type="radio" name="rememberme" value="0" />
							<label for="loginguard-rememberme-no" class="red"><?= Text::_('JNO') ?></label>
						</div>
					</div>
				</div>
		    <?php endif;?>
        </div>

		<div id="loginguard-captive-form-all-buttons">
			<button class="loginguard-button-primary--large"
					id="loginguard-captive-button-submit"
					style="<?= $this->renderOptions['hide_submit'] ? 'display: none' : '' ?>"
					type="submit">
				<span class="icon icon-arrow-right" aria-hidden="true"></span>
				<?= Text::_('COM_LOGINGUARD_LBL_VALIDATE'); ?>
			</button>

			<div id="loginguard-captive-form-standard-buttons">
				<?php if ($this->isAdmin): ?>
					<a href="<?= Route::_('index.php?option=com_login&task=logout&' . Factory::getApplication()->getFormToken() . '=1') ?>"
					   class="loginguard-button-danger"
					   id="loginguard-captive-button-logout">
						<span class="icon icon-lock" aria-hidden="true"></span>
						<?= Text::_('COM_LOGINGUARD_LBL_LOGOUT'); ?>
					</a>
				<?php else: ?>
					<a href="<?= Route::_('index.php?option=com_users&task=user.logout&' . Factory::getApplication()->getFormToken() . '=1') ?>"
					   class="loginguard-button-danger" id="loginguard-captive-button-logout">
						<span class="icon icon-lock" aria-hidden="true"></span>
						<?= Text::_('COM_LOGINGUARD_LBL_LOGOUT'); ?>
					</a>
				<?php endif; ?>
				<?php if (count($this->records) > 1): ?>
					<div id="loginguard-captive-form-choose-another">
						<a href="<?= Route::_('index.php?option=com_loginguard&view=captive&task=select') ?>"
						   class="loginguard-button-ghost"
						>
							<?= Text::_('COM_LOGINGUARD_LBL_USEDIFFERENTMETHOD'); ?>
						</a>
					</div>
				<?php endif; ?>
			</div>
		</div>
    </form>

	<?php if ($this->renderOptions['post_message']): ?>
        <div class="loginguard-captive-post-message">
	        <?= $this->renderOptions['post_message'] ?>
        </div>
	<?php endif; ?>

</div>